juliet package
==============

Submodules
----------

juliet.fit module
-----------------

.. automodule:: juliet.fit
   :members:
   :undoc-members:
   :show-inheritance:

juliet.plots module
-------------------

.. automodule:: juliet.plots
   :members:
   :undoc-members:
   :show-inheritance:

juliet.utils module
-------------------

.. automodule:: juliet.utils
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: juliet
   :members:
   :undoc-members:
   :show-inheritance:
